@@ -1,6 +1,4 @@
-import os
-import json
-import requests
+import os, json, requests, websocket as ws
 from functools import lru_cache
 
 
@@ -11,6 +9,9 @@ def get_info_from_token(api_token):
         headers={"content-type": "application/json", "API-Authorization": api_token},
     )
     response_json = response.json()
+    if response_json is None:
+        return None, None
+
     author_id = response_json.get("author_id")
     workspaces = response_json.get("workspaces", [{}])
 
@@ -21,7 +22,7 @@ def get_info_from_token(api_token):
     return workspace_id, author_id
 
 
-def usage(f, args, kwargs, author_id, workspace_id):
+def usage(fname, args, kwargs, author_id, workspace_id):
     if os.getenv("DISABLE_USAGE_STATISTICS"):
         return
 
@@ -32,7 +33,7 @@ def usage(f, args, kwargs, author_id, workspace_id):
                 {
                     "author_id": author_id,
                     "workspace_id": workspace_id,
-                    "method": f.__name__,
+                    "method": fname,
                     "arguments": {"args": args[1:], "kwargs": list(kwargs.keys())},
                 }
             ),
@@ -40,3 +41,18 @@ def usage(f, args, kwargs, author_id, workspace_id):
         )
     except Exception as e:
         pass
+
+
+def wait_for_api_token(cli_uuid):
+    ws_url = f"wss://pubsub.abstra.cloud/external/sub/cli-login-{cli_uuid}"
+    ws_client = None
+    try:
+        ws_client = ws.create_connection(ws_url)
+        result = ws_client.recv()
+        if result is None:
+            return None
+        return json.loads(result).get("api_token")
+    except Exception as e:
+        return None
+    finally:
+        ws_client and ws_client.close()
