@@ -22,6 +22,10 @@ class Files(Resource):
             elif os.path.isdir(path):
                 files.extend(utils.files_from_directory(path))
 
+        if len(files) == 0:
+            messages.no_files()
+            return
+
         bar = messages.show_progress("Uploading files", len(files))
         for path in files:
             filename = path.as_posix()
@@ -47,3 +51,13 @@ class Files(Resource):
                 bar.next()
         bar.finish()
         print(f"\nDeleted {len(args)} files successfully")
+
+    @staticmethod
+    def list_dashes_files(dashes_root_path):
+        files = apis.list_workspace_files()
+        return [
+            f["Key"]
+            for f in files
+            if f["Key"].startswith(f"{dashes_root_path}/")
+            and f["Key"].endswith(".abstradash.json")
+        ]
